ApiConfig class

Implemented types

Constructors

ApiConfig(Map<String, dynamic> params)

Properties

callbackUrl ↔ String?
getter/setter pairoverride
chunkSize ↔ int?
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout ↔ int?
getter/setter pairoverride
uploadPrefix ↔ String?
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited