CloudConfig class

Mixed-in types

Constructors

CloudConfig(String cloudName, String apiKey, String apiSecret, {String? signatureAlgorithm})
CloudConfig.withMap(Map<String, dynamic> params)

Properties

apiKey ↔ String?
getter/setter pairinherited
apiSecret ↔ String?
getter/setter pairinherited
authToken ↔ AuthToken?
getter/setter pairinherited
cloudName ↔ String?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
oauthToken ↔ String?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatureAlgorithm ↔ String
getter/setter pairinherited
signatureVersion ↔ int
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited