BackgroundRemoval class

Class BackgroundRemoval fineedges hints - objects to search for. (List can be found in ForegroundObject)

Inheritance

Constructors

BackgroundRemoval({bool? fineEdges, List<ForegroundObject>? hints})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fineEdges(bool fineEdges) → BackgroundRemoval
hints(List<ForegroundObject> hints) → BackgroundRemoval
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited