Cartoonify class

Class Cartoonify lineStrength The thickness of the lines. (Range: 0 to 100, Server default: 50) colorReduction The decrease in the number of colors and corresponding saturation boost of the remaining colors. (Range: 0 to 100, Server default: automatically adjusts according to the line_strength value). Higher reduction values result in a less realistic look.

Inheritance

Constructors

Cartoonify({dynamic lineStrength, dynamic colorReductionLevel, bool? blackwhite})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

blackwhite([bool blackwhite = true]) → Cartoonify
Converts the image to black and white.
override
colorReductionLevel(dynamic colorReductionLevel) → Cartoonify
lineStrength(dynamic lineStrength) → Cartoonify
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited