ZoomPan class

Inheritance

Constructors

ZoomPan({ZoomPanMode? mode, int? maxZoom, int? duration})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

duration(int duration) → ZoomPan
from(ZoomPanArea from) → ZoomPan
maxZoom(int maxZoom) → ZoomPan
mode(ZoomPanMode mode) → ZoomPan
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
to(ZoomPanArea to) → ZoomPan
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited