ZoomPanAreaTo class

Inheritance

Constructors

ZoomPanAreaTo(ZoomPanArea area)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pairinherited

Methods

gravity(Gravity gravity) → ZoomPanArea
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
x(int x) → ZoomPanArea
inherited
y(int y) → ZoomPanArea
inherited
zoom(int zoom) → ZoomPanArea
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited