Custom class

Inheritance

Constructors

Custom()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

height(dynamic height) → Custom
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
width(dynamic width) → Custom
x(dynamic x) → Custom
y(dynamic y) → Custom

Operators

operator ==(Object other) → bool
The equality operator.
inherited